=================
Interfaces
=================
.. toctree::
   :maxdepth: 1

   trakt/trakt.interfaces.auth
   trakt/trakt.interfaces.calendars
   trakt/trakt.interfaces.movies
   trakt/trakt.interfaces.oauth
   trakt/trakt.interfaces.oauth.device
   trakt/trakt.interfaces.oauth.pin
   trakt/trakt.interfaces.scrobble
   trakt/trakt.interfaces.search
   trakt/trakt.interfaces.shows
   trakt/trakt.interfaces.sync
   trakt/trakt.interfaces.sync.collection
   trakt/trakt.interfaces.sync.history
   trakt/trakt.interfaces.sync.playback
   trakt/trakt.interfaces.sync.ratings
   trakt/trakt.interfaces.sync.watched
   trakt/trakt.interfaces.sync.watchlist
   trakt/trakt.interfaces.users
   trakt/trakt.interfaces.users.following
   trakt/trakt.interfaces.users.friends
   trakt/trakt.interfaces.users.history
   trakt/trakt.interfaces.users.lists
   trakt/trakt.interfaces.users.lists.list_
   trakt/trakt.interfaces.users.ratings
   trakt/trakt.interfaces.users.settings
   trakt/trakt.interfaces.users.watchlist
